========
Concepts
========

Explore the links to learn more about conda foundations.

.. toctree::
   :maxdepth: 1

   conda-commands
   packages
   pkg-specs
   channels
   environments
   installing-with-conda
   conda-performance
   data-science

When you're comfortable with the conda concepts, learn how to :doc:`get started using conda <../getting-started>`.
